@@ -1,4 +1,4 @@
-from jh_utils.pandas import sql
+from jh_utils.data.pandas import sql
 import dask as dd
 
 def migrate_table_pandas(query, table_name, engine_origin, engine_destiny, destiny_schema, if_exists):
